@@ -4,6 +4,7 @@ use libc::{
     c_char, c_int, c_ulong, c_void, close, execvp, exit, fork, size_t, waitpid, E2BIG, EILSEQ,
     EINVAL,
 };
+use md5;
 use percent_encoding::*;
 use std::ffi::CString;
 use std::fs::DirBuilder;
@@ -152,6 +153,12 @@ pub fn get_default_browser() -> String {
     env::var("BROWSER").unwrap_or_else(|_| "lynx".to_string())
 }
 
+pub fn md5hash(input: &str) -> String {
+    let digest = md5::compute(input);
+    let hash = format!("{:x}", digest);
+    hash
+}
+
 pub fn trim(rs_str: String) -> String {
     rs_str.trim().to_string()
 }
@@ -445,13 +452,15 @@ pub fn run_command(cmd: &str, param: &str) {
                     let c_arg = [c_cmd.as_ptr(), c_param.as_ptr(), ptr::null()];
                     execvp(c_cmd.as_ptr(), c_arg.as_ptr());
                 }
-                _ => log!(
-                    Level::UserError,
-                    "Conversion of \"{}\" and/or \"{}\" to CString failed.",
-                    cmd,
-                    param
-                ),
-            };
+                _ => {
+                    log!(
+                        Level::UserError,
+                        "Conversion of \"{}\" and/or \"{}\" to CString failed.",
+                        cmd,
+                        param
+                    );
+                }
+            }
         }
 
         // Child process or grand child in case of failure to execvp, in both cases nothing to do.
@@ -561,7 +570,7 @@ pub fn run_interactively(command: &str, caller: &str) -> Option<u8> {
             log!(
                 Level::Warn,
                 &format!("{}: Couldn't create child process: {}", caller, err)
-            )
+            );
         })
         .ok()
         .and_then(|exit_status| exit_status.code())
@@ -583,7 +592,7 @@ pub fn run_non_interactively(command: &str, caller: &str) -> Option<u8> {
             log!(
                 Level::Warn,
                 &format!("{}: Couldn't create child process: {}", caller, err)
-            )
+            );
         })
         .ok()
         .and_then(|exit_status| exit_status.code())
@@ -710,6 +719,72 @@ pub fn strip_comments(line: &str) -> &str {
     &line[0..first_pound_chr_idx]
 }
 
+fn get_escape_value(c: char) -> String {
+    match c {
+        'n' => "\n".to_owned(),
+        'r' => "\r".to_owned(),
+        't' => "\t".to_owned(),
+        '"' => "\"".to_owned(),
+        // escaped backticks are passed through, still escaped. We un-escape
+        // them in ConfigParser::evaluate_backticks
+        '`' => "\\`".to_owned(),
+        '\\' => "\\".to_owned(),
+        x => x.to_owned().to_string(),
+    }
+}
+
+pub fn extract_token_quoted<'a>(line: &'a str, delimiters: &str) -> (Option<String>, &'a str) {
+    let first_non_delimiter = line.find(|c| !delimiters.contains(c));
+    let line = match first_non_delimiter {
+        Some(x) => &line[x..],
+        None => return (None, ""),
+    };
+
+    if line.starts_with('#') {
+        return (None, "");
+    }
+
+    if line.starts_with('"') {
+        let mut token = String::new();
+        let mut it = line.chars();
+        it.next(); // Ignore opening quotation mark
+        while let Some(c) = it.next() {
+            if c == '"' {
+                return (Some(token), it.as_str());
+            } else if c == '\\' {
+                if let Some(escaped_char) = it.next() {
+                    token.push_str(&get_escape_value(escaped_char));
+                }
+            } else {
+                token.push(c);
+            }
+        }
+        (Some(token), "")
+    } else {
+        let end_of_token = line.find(|c| delimiters.contains(c));
+        match end_of_token {
+            Some(x) => (Some(line[..x].to_owned()), &line[x..]),
+            None => (Some(line.to_owned()), ""),
+        }
+    }
+}
+
+/// Tokenize strings, obeying quotes and throwing away comments that start with a '#'
+pub fn tokenize_quoted(line: &str, delimiters: &str) -> Vec<String> {
+    let mut tokens = Vec::new();
+
+    let mut todo = line;
+    while !todo.is_empty() {
+        let (token, remainder) = extract_token_quoted(todo, delimiters);
+        if let Some(x) = token {
+            tokens.push(x);
+        }
+        todo = remainder;
+    }
+
+    tokens
+}
+
 /// The result of executing `extract_filter()`.
 pub struct FilterUrlParts {
     /// "~/bin/foo.sh" in "filter:~/bin/foo.sh:https://example.com/news.atom"
@@ -1039,6 +1114,191 @@ mod tests {
         );
     }
 
+    #[test]
+    fn t_extract_token_quoted_ignores_comments() {
+        let delimiters = " \r\n\t";
+        assert_eq!(
+            extract_token_quoted("\t\t  # commented out", delimiters),
+            (None, "")
+        );
+
+        // ignores '#' if it is inside quotes
+        assert_eq!(
+            extract_token_quoted(r##""# in quoted token" other tokens"##, delimiters),
+            (Some(r#"# in quoted token"#.to_owned()), " other tokens")
+        );
+
+        // token before start of comment
+        assert_eq!(
+            extract_token_quoted(r#"some-token # some comment"#, delimiters),
+            (Some("some-token".to_owned()), " # some comment")
+        );
+    }
+
+    #[test]
+    fn t_extract_token_quoted_ignores_delimiters_in_front_of_tokens() {
+        // empty delimiters
+        assert_eq!(
+            extract_token_quoted("\n\r\t \n\t\r token-name", ""),
+            (Some("\n\r\t \n\t\r token-name".to_owned()), "")
+        );
+
+        // single delimiter
+        assert_eq!(
+            extract_token_quoted("--token name--", "-"),
+            (Some("token name".to_owned()), "--")
+        );
+
+        // two delimiters
+        assert_eq!(
+            extract_token_quoted("--token name--", " -"),
+            (Some("token".to_owned()), " name--")
+        );
+    }
+
+    #[test]
+    fn t_extract_token_quoted_ignores_delimiters_in_quoted_strings() {
+        assert_eq!(
+            extract_token_quoted(r#"  "token name"  "#, " \r\n\t"),
+            (Some("token name".to_owned()), "  ")
+        );
+
+        assert_eq!(
+            extract_token_quoted(r#"--"token name"--"#, " -"),
+            (Some("token name".to_owned()), "--")
+        );
+    }
+
+    #[test]
+    fn t_extract_token_quoted_processes_escape_sequences_in_quoted_strings() {
+        assert_eq!(
+            extract_token_quoted(r#"  "\n \r \t \" \` \\ " remainder"#, " \r\n\t"),
+            (Some("\n \r \t \" \\` \\ ".to_owned()), " remainder")
+        );
+    }
+
+    #[test]
+    fn t_tokenize_quoted_splits_on_delimiters() {
+        assert_eq!(
+            tokenize_quoted("asdf \"foobar bla\" \"foo\\r\\n\\tbar\"", " \r\n\t"),
+            vec!["asdf", "foobar bla", "foo\r\n\tbar"]
+        );
+
+        assert_eq!(
+            tokenize_quoted("  \"foo \\\\xxx\"\t\r \" \"", " \r\n\t"),
+            vec!["foo \\xxx", " "]
+        );
+    }
+
+    #[test]
+    fn t_tokenize_quoted_stops_at_closing_quotation_mark() {
+        assert_eq!(
+            tokenize_quoted(r#"set browser "mpv %u";"#, " "),
+            vec!["set", "browser", "mpv %u", ";"]
+        );
+    }
+
+    #[test]
+    fn t_tokenize_quoted_implicitly_closes_quotes_at_end_of_string() {
+        assert_eq!(tokenize_quoted("\"\\\\", " "), vec!["\\"]);
+
+        assert_eq!(
+            tokenize_quoted("\"\\\\\" and \"some other stuff", " "),
+            vec!["\\", "and", "some other stuff"]
+        );
+
+        // Backslash at end of string is ignored
+        assert_eq!(tokenize_quoted(r#""abc\"#, " "), vec!["abc"]);
+    }
+
+    #[test]
+    fn t_tokenize_quoted_interprets_double_backslash_as_literal_backslash() {
+        assert_eq!(tokenize_quoted(r#""""#, ""), vec![""]);
+
+        assert_eq!(tokenize_quoted(r#""\\""#, ""), vec![r#"\"#]);
+
+        assert_eq!(tokenize_quoted(r##""#\\""##, ""), vec!["#\\"]);
+
+        assert_eq!(tokenize_quoted(r#""'#\\'""#, ""), vec!["'#\\'"]);
+
+        assert_eq!(tokenize_quoted(r#""'#\\ \\'""#, ""), vec![r#"'#\ \'"#]);
+
+        assert_eq!(tokenize_quoted("\"\\\\\\\\", ""), vec![r#"\\"#]);
+
+        assert_eq!(tokenize_quoted("\"\\\\\\\\\\\\", ""), vec![r#"\\\"#]);
+
+        assert_eq!(tokenize_quoted("\"\\\\\\\\\"", ""), vec![r#"\\"#]);
+
+        assert_eq!(tokenize_quoted("\"\\\\\\\\\\\\\"", ""), vec![r#"\\\"#]);
+
+        assert_eq!(tokenize_quoted(r#""\\bgit\\b""#, ""), vec![r#"\bgit\b"#]);
+
+        assert_eq!(
+            tokenize_quoted(
+                r#"browser "/Applications/Google\\ Chrome.app/Contents/MacOS/Google\\ Chrome --app %u""#,
+                " "
+            ),
+            vec![
+                "browser",
+                r#"/Applications/Google\ Chrome.app/Contents/MacOS/Google\ Chrome --app %u"#
+            ]
+        );
+    }
+
+    #[test]
+    fn t_tokenize_quoted_keeps_backticks_escaped() {
+        assert_eq!(
+            tokenize_quoted("asdf \"\\`foobar `bla`\\`\"", " "),
+            vec!["asdf", "\\`foobar `bla`\\`"]
+        );
+    }
+
+    #[test]
+    fn t_tokenize_quoted_stops_at_comment_starting_with_pound_character() {
+        //	A string consisting of just a comment
+        assert!(tokenize_quoted("# just a comment", " ").is_empty());
+
+        //	A string with one quoted substring
+        assert_eq!(
+            tokenize_quoted(r#""a test substring" # !!!"#, " "),
+            vec!["a test substring"]
+        );
+
+        //	A string with two quoted substrings
+        assert_eq!(
+            tokenize_quoted(r#""first sub" "snd" # comment"#, " "),
+            vec!["first sub", "snd"]
+        );
+
+        //	A comment containing # character
+        assert_eq!(
+            tokenize_quoted(r#"one # a comment with # char"#, " "),
+            vec!["one"]
+        );
+
+        //	A # character inside quoted substring is ignored
+        assert_eq!(
+            tokenize_quoted(r#"this "will # be" ignored"#, " "),
+            vec!["this", "will # be", "ignored"]
+        );
+    }
+
+    #[test]
+    fn t_tokenize_quoted_ignores_escaped_pound_sign_start_of_token() {
+        assert_eq!(
+            tokenize_quoted(r#"one \# two three # ???"#, " "),
+            vec!["one", "\\#", "two", "three"]
+        );
+    }
+
+    #[test]
+    fn t_extract_token_quoted_works_with_unicode_strings() {
+        assert_eq!(
+            extract_token_quoted(r#""привет мир" Юникода"#, " \r\n\t"),
+            (Some("привет мир".to_owned()), " Юникода")
+        );
+    }
+
     #[test]
     fn t_to_u() {
         assert_eq!(to_u(String::from("0"), 10), 0);
