@@ -775,7 +775,7 @@ std::vector<std::shared_ptr<RssItem>> Controller::search_for_items(
 		}
 	} else {
 		items = rsscache->search_for_items(
-				query, (feed != nullptr ? feed->rssurl() : ""));
+				query, (feed != nullptr ? feed->rssurl() : ""), ign);
 		for (const auto& item : items) {
 			item->set_feedptr(
 				feedcontainer.get_feed_by_url(item->feedurl()));
@@ -916,7 +916,23 @@ std::string Controller::write_temporary_item(std::shared_ptr<RssItem> item)
 void Controller::write_item(std::shared_ptr<RssItem> item,
 	const std::string& filename)
 {
-	std::fstream f(filename, std::fstream::out);
+	const std::string save_path = cfg.get_configvalue("save-path");
+	auto spath = save_path.back() == '/' ? save_path : save_path + "/";
+
+	std::string path;
+	switch (filename[0]) {
+	case '/':
+		path = filename;
+		break;
+	case '~':
+		path = utils::resolve_tilde(filename);
+		break;
+	default:
+		path = spath + filename;
+		break;
+	}
+
+	std::fstream f(path, std::fstream::out);
 	if (!f.is_open()) {
 		throw Exception(errno);
 	}
