@@ -294,30 +294,35 @@ REDO:
 		}
 		break;
 	case OP_MARKFEEDREAD: {
-		LOG(Level::INFO,
-			"FeedListFormAction: marking feed read at position "
-			"`%s'",
-			feedpos);
-		if (visible_feeds.size() > 0 && feedpos.length() > 0) {
-			try {
-				{
-					const auto message_lifetime = v->get_statusline().show_message_until_finished(
-							_("Marking feed read..."));
-					v->get_ctrl()->mark_all_read(pos);
-					do_redraw = true;
+		if (!cfg->get_configvalue_as_bool(
+				"confirm-mark-feed-read") ||
+			v->confirm(_("Do you really want to mark this feed as read (y:Yes n:No)? "),
+				_("yn")) == *_("y")) {
+			LOG(Level::INFO,
+				"FeedListFormAction: marking feed read at position "
+				"`%s'",
+				feedpos);
+			if (visible_feeds.size() > 0 && feedpos.length() > 0) {
+				try {
+					{
+						const auto message_lifetime = v->get_statusline().show_message_until_finished(
+								_("Marking feed read..."));
+						v->get_ctrl()->mark_all_read(pos);
+						do_redraw = true;
+					}
+					bool show_read = cfg->get_configvalue_as_bool("show-read-feeds");
+					if (visible_feeds.size() > (pos + 1) && show_read) {
+						list.set_position(pos + 1);
+					}
+				} catch (const DbException& e) {
+					v->get_statusline().show_error(strprintf::fmt(
+							_("Error: couldn't mark feed read: %s"),
+							e.what()));
 				}
-				bool show_read = cfg->get_configvalue_as_bool("show-read-feeds");
-				if (visible_feeds.size() > (pos + 1) && show_read) {
-					list.set_position(pos + 1);
-				}
-			} catch (const DbException& e) {
-				v->get_statusline().show_error(strprintf::fmt(
-						_("Error: couldn't mark feed read: %s"),
-						e.what()));
+			} else {
+				v->get_statusline().show_error(
+					_("No feed selected!")); // should not happen
 			}
-		} else {
-			v->get_statusline().show_error(
-				_("No feed selected!")); // should not happen
 		}
 	}
 	break;
@@ -824,26 +829,41 @@ void FeedListFormAction::handle_cmdline(const std::string& cmd)
 		handle_cmdline_num(idx);
 	} else {
 		// hand over all other commands to formaction
-		std::vector<std::string> tokens =
-			utils::tokenize_quoted(cmd, " \t");
-		if (!tokens.empty()) {
-			if (tokens[0] == "tag") {
-				if (tokens.size() >= 2 && tokens[1] != "") {
-					tag = tokens[1];
-					do_redraw = true;
-					zero_feedpos = true;
-				}
-			} else if (tokens[0] == "goto") {
-				if (tokens.size() >= 2 && tokens[1] != "") {
-					goto_feed(tokens[1]);
-				}
-			} else {
-				FormAction::handle_cmdline(cmd);
+		constexpr auto delimiters = " \t";
+		const auto command = FormAction::parse_command(cmd, delimiters);
+		switch (command.type) {
+		case CommandType::TAG:
+			if (!command.args.empty()) {
+				handle_tag(command.args.front());
 			}
+			break;
+		case CommandType::GOTO:
+			if (!command.args.empty()) {
+				handle_goto(command.args.front());
+			}
+			break;
+		default:
+			FormAction::handle_parsed_command(command);
 		}
 	}
 }
 
+void FeedListFormAction::handle_tag(const std::string& tag_param)
+{
+	if (tag_param != "") {
+		tag = tag_param;
+		do_redraw = true;
+		zero_feedpos = true;
+	}
+}
+
+void FeedListFormAction::handle_goto(const std::string& param)
+{
+	if (param != "") {
+		goto_feed(param);
+	}
+}
+
 void FeedListFormAction::finished_qna(Operation op)
 {
 	FormAction::finished_qna(op); // important!
