@@ -2,6 +2,7 @@
 
 #include <cassert>
 #include <cinttypes>
+#include <exception>
 #include <ncurses.h>
 
 #include "config.h"
@@ -255,75 +256,110 @@ void FormAction::handle_cmdline(const std::string& cmdline)
 	 * It works the same way basically everywhere: first the command line
 	 * is tokenized, and then the tokens are looked at.
 	 */
-	std::vector<std::string> tokens =
-		utils::tokenize_quoted(cmdline, " \t=");
+	constexpr auto delimiters = " \t=";
+	const auto command = FormAction::parse_command(cmdline, delimiters);
 	assert(cfg != nullptr);
-	if (!tokens.empty()) {
-		std::string cmd = tokens[0];
-		tokens.erase(tokens.begin());
-		if (cmd == "set") {
-			if (tokens.size() == 1) {
-				const std::string var = tokens[0];
-				if (handle_single_argument_set(var)) {
-					return;
-				}
-				v->get_statusline().show_message(strprintf::fmt("  %s=%s",
-						var,
-						utils::quote_if_necessary(cfg->get_configvalue(var))));
-			} else if (tokens.size() == 2) {
-				std::string result = ConfigParser::evaluate_backticks(tokens[1]);
-				utils::trim_end(result);
-				cfg->set_configvalue(tokens[0], result);
-				// because some configuration value might have changed something UI-related
-				set_redraw(true);
-			} else {
-				v->get_statusline().show_error(
-					_("usage: set <variable>[=<value>]"));
-			}
-		} else if (cmd == "q" || cmd == "quit") {
-			while (v->formaction_stack_size() > 0) {
-				v->pop_current_formaction();
-			}
-		} else if (cmd == "source") {
-			if (tokens.empty()) {
-				v->get_statusline().show_error(_("usage: source <file> [...]"));
-			} else {
-				for (const auto& token : tokens) {
-					try {
-						v->get_ctrl()->load_configfile(
-							utils::resolve_tilde(
-								token));
-					} catch (const ConfigException& ex) {
-						v->get_statusline().show_error(ex.what());
-						break;
-					}
-				}
-			}
-		} else if (cmd == "dumpconfig") {
-			if (tokens.size() != 1) {
-				v->get_statusline().show_error(_("usage: dumpconfig <file>"));
-			} else {
-				v->get_ctrl()->dump_config(
-					utils::resolve_tilde(tokens[0]));
-				v->get_statusline().show_message(strprintf::fmt(
-						_("Saved configuration to %s"),
-						tokens[0]));
-			}
-		} else if (cmd == "exec") {
-			if (tokens.size() != 1) {
-				v->get_statusline().show_error(_("usage: exec <operation>"));
-			} else {
-				const auto op = v->get_keymap()->get_opcode(tokens[0]);
-				if (op != OP_NIL) {
-					process_op(op);
-				} else {
-					v->get_statusline().show_error(_("Operation not found"));
-				}
-			}
-		} else {
-			v->get_statusline().show_error(strprintf::fmt(
-					_("Not a command: %s"), cmdline));
+	handle_parsed_command(command);
+}
+
+void FormAction::handle_set(const std::vector<std::string>& args)
+{
+	if (args.size() == 1) {
+		if (handle_single_argument_set(args[0])) {
+			return;
 		}
+		v->get_statusline().show_message(strprintf::fmt("  %s=%s",
+				args[0],
+				utils::quote_if_necessary(cfg->get_configvalue(args[0]))));
+	} else if (args.size() == 2) {
+		std::string result = ConfigParser::evaluate_backticks(args[1]);
+		utils::trim_end(result);
+		cfg->set_configvalue(args[0], result);
+		// because some configuration value might have changed something UI-related
+		set_redraw(true);
+	} else {
+		v->get_statusline().show_error(
+			_("usage: set <variable>[=<value>]"));
+	}
+}
+
+void FormAction::handle_quit()
+{
+	while (v->formaction_stack_size() > 0) {
+		v->pop_current_formaction();
+	}
+}
+
+void FormAction::handle_source(const std::vector<std::string>& args)
+{
+	if (args.empty()) {
+		v->get_statusline().show_error(_("usage: source <file> [...]"));
+	} else {
+		for (const auto& param : args) {
+			try {
+				v->get_ctrl()->load_configfile(
+					utils::resolve_tilde(
+						param));
+			} catch (const ConfigException& ex) {
+				v->get_statusline().show_error(ex.what());
+				break;
+			}
+		}
+	}
+}
+
+void FormAction::handle_dumpconfig(const std::vector<std::string>& args)
+{
+	if (args.size() != 1) {
+		v->get_statusline().show_error(_("usage: dumpconfig <file>"));
+	} else {
+		v->get_ctrl()->dump_config(
+			utils::resolve_tilde(args[0]));
+		v->get_statusline().show_message(strprintf::fmt(
+				_("Saved configuration to %s"),
+				args[0]));
+	}
+}
+
+void FormAction::handle_exec(const std::vector<std::string>& args)
+{
+	if (args.size() != 1) {
+		v->get_statusline().show_error(_("usage: exec <operation>"));
+	} else {
+		const auto op = v->get_keymap()->get_opcode(args[0]);
+		if (op != OP_NIL) {
+			process_op(op);
+		} else {
+			v->get_statusline().show_error(_("Operation not found"));
+		}
+	}
+}
+
+void FormAction::handle_parsed_command(const Command& command)
+{
+	switch (command.type) {
+	case CommandType::SET:
+		handle_set(command.args);
+		break;
+	case CommandType::QUIT:
+		handle_quit();
+		break;
+	case CommandType::SOURCE:
+		handle_source(command.args);
+		break;
+	case CommandType::DUMPCONFIG:
+		handle_dumpconfig(command.args);
+		break;
+	case CommandType::EXEC:
+		handle_exec(command.args);
+		break;
+	case CommandType::UNKNOWN:
+		v->get_statusline().show_error(strprintf::fmt(_("Not a command: %s"), command.args[0]));
+		break;
+	case CommandType::INVALID:
+		break;
+	default:
+		break;
 	}
 }
 
@@ -421,52 +457,45 @@ void FormAction::finished_qna(Operation op)
 
 void FormAction::start_bookmark_qna(const std::string& default_title,
 	const std::string& default_url,
-	const std::string& default_desc,
 	const std::string& default_feed_title)
 {
 	LOG(Level::DEBUG,
 		"FormAction::start_bookmark_qna: starting bookmark Q&A... "
-		"default_title = %s default_url = %s default_desc = %s "
+		"default_title = %s default_url = %s "
 		"default_feed_title = %s",
 		default_title,
 		default_url,
-		default_desc,
 		default_feed_title);
 	std::vector<QnaPair> prompts;
 
-	std::string new_title = "";
-	bool is_bm_autopilot =
-		cfg->get_configvalue_as_bool("bookmark-autopilot");
+	bool is_bm_autopilot = cfg->get_configvalue_as_bool("bookmark-autopilot");
 	prompts.push_back(QnaPair(_("URL: "), default_url));
 	// call the function to figure out title from url only if the default_title is no good
 	if (default_title.empty()) {
-		new_title = utils::make_title(default_url);
-		prompts.push_back(QnaPair(_("Title: "), new_title));
+		prompts.push_back(QnaPair(_("Title: "), utils::make_title(default_url)));
 	} else {
 		prompts.push_back(QnaPair(_("Title: "), utils::utf8_to_locale(default_title)));
 	}
-	prompts.push_back(QnaPair(_("Description: "), default_desc));
+	prompts.push_back(QnaPair(_("Description: "), ""));
 	prompts.push_back(QnaPair(_("Feed title: "), default_feed_title));
 
-	if (is_bm_autopilot) { // If bookmarking is set to autopilot don't
-		// prompt for url, title, desc
+	if (is_bm_autopilot) { // If bookmarking is set to autopilot don't prompt for url, title, desc
+		std::string title;
 		if (default_title.empty()) {
-			new_title = utils::make_title(
-					default_url); // try to make the title from url
+			title = utils::make_title(default_url); // try to make the title from url
 		} else {
 			// assignment just to make the call to bookmark() below easier
-			new_title = utils::utf8_to_locale(default_title);
+			title = utils::utf8_to_locale(default_title);
 		}
 
 		// if url or title is missing, abort autopilot and ask user
-		if (default_url.empty() || new_title.empty() ||
-			default_feed_title.empty()) {
+		if (default_url.empty() || title.empty()) {
 			start_qna(prompts, OP_INT_BM_END);
 		} else {
 			v->get_statusline().show_message(_("Saving bookmark on autopilot..."));
 			std::string retval = bookmark(default_url,
-					new_title,
-					default_desc,
+					title,
+					"",
 					default_feed_title);
 			if (retval.length() == 0) {
 				v->get_statusline().show_message(_("Saved bookmark."));
@@ -485,6 +514,38 @@ void FormAction::start_bookmark_qna(const std::string& default_title,
 	}
 }
 
+Command FormAction::parse_command(const std::string& input,
+	std::string delimiters)
+{
+	auto tokens = utils::tokenize_quoted(input, delimiters);
+	if (tokens.empty()) {
+		return Command { .type = CommandType::INVALID, .args = {} };
+	} else {
+		auto cmd_name = tokens.front();
+		tokens.erase(tokens.begin());
+		if (cmd_name == "set") {
+			return Command { .type = CommandType::SET, .args = std::move(tokens) };
+		} else if (cmd_name == "q" || cmd_name == "quit") {
+			return Command { .type = CommandType::QUIT, .args = std::move(tokens) };
+		} else if (cmd_name == "source") {
+			return Command { .type = CommandType::SOURCE, .args = std::move(tokens) };
+		} else if (cmd_name == "dumpconfig") {
+			return Command { .type = CommandType::DUMPCONFIG, .args = std::move(tokens) };
+		} else if (cmd_name == "exec") {
+			return Command { .type = CommandType::EXEC, .args = std::move(tokens) };
+		} else if (cmd_name == "tag") {
+			return Command { .type = CommandType::TAG, .args = std::move(tokens) };
+		} else if (cmd_name == "goto") {
+			return Command { .type = CommandType::GOTO, .args = std::move(tokens) };
+		} else if (cmd_name == "save") {
+			return Command { .type = CommandType::SAVE, .args = std::move(tokens) };
+		} else {
+			tokens.insert(tokens.begin(), std::move(cmd_name));
+			return Command { .type = CommandType::UNKNOWN, .args = std::move(tokens) };
+		}
+	}
+}
+
 void FormAction::start_next_question()
 {
 	/*
