@@ -216,12 +216,20 @@ void RssParser::download_http(const std::string& uri)
 		if (!ign || !ign->matches_lastmodified(uri)) {
 			ch->fetch_lastmodified(uri, lm, etag);
 		}
-		f = p.parse_url(uri,
-				lm,
-				etag,
-				api,
-				cfgcont->get_configvalue("cookie-cache"),
-				easyhandle ? easyhandle->ptr() : 0);
+		if (easyhandle) {
+			f = p.parse_url(uri,
+					*easyhandle,
+					lm,
+					etag,
+					api,
+					cfgcont->get_configvalue("cookie-cache"));
+		} else {
+			f = p.parse_url(uri,
+					lm,
+					etag,
+					api,
+					cfgcont->get_configvalue("cookie-cache"));
+		}
 		LOG(Level::DEBUG,
 			"RssParser::download_http: lm = %" PRId64 " etag = %s",
 			// On GCC, `time_t` is `long int`, which is at least 32 bits
@@ -517,8 +525,8 @@ void RssParser::set_item_content(std::shared_ptr<RssItem> x,
 		!x->link().empty()) {
 
 		CurlHandle handle;
-		const std::string content = utils::retrieve_url(x->link(), cfgcont, "", nullptr,
-				HTTPMethod::GET, handle.ptr());
+		const std::string content = utils::retrieve_url(x->link(), handle, cfgcont, "", nullptr,
+				HTTPMethod::GET);
 		std::string content_mime_type;
 
 		// Determine mime-type based on Content-type header:
@@ -643,8 +651,13 @@ void RssParser::fetch_ttrss(const std::string& feed_id)
 {
 	TtRssApi* tapi = dynamic_cast<TtRssApi*>(api);
 	if (tapi) {
-		f = tapi->fetch_feed(
-				feed_id, easyhandle ? easyhandle->ptr() : nullptr);
+		if (easyhandle) {
+			f = tapi->fetch_feed(
+					feed_id, *easyhandle);
+		} else {
+			f = tapi->fetch_feed(
+					feed_id);
+		}
 	}
 	LOG(Level::DEBUG,
 		"RssParser::fetch_ttrss: f.items.size = %" PRIu64,
@@ -677,7 +690,11 @@ void RssParser::fetch_miniflux(const std::string& feed_id)
 {
 	MinifluxApi* mapi = dynamic_cast<MinifluxApi*>(api);
 	if (mapi) {
-		f = mapi->fetch_feed(feed_id, easyhandle ? easyhandle->ptr() : nullptr);
+		if (easyhandle) {
+			f = mapi->fetch_feed(feed_id, *easyhandle);
+		} else {
+			f = mapi->fetch_feed(feed_id);
+		}
 	}
 	LOG(Level::INFO,
 		"RssParser::fetch_miniflux: f.items.size = %" PRIu64,
@@ -688,7 +705,12 @@ void RssParser::fetch_freshrss(const std::string& feed_id)
 {
 	FreshRssApi* fapi = dynamic_cast<FreshRssApi*>(api);
 	if (fapi) {
-		f = fapi->fetch_feed(feed_id, easyhandle ? easyhandle->ptr() : nullptr);
+		if (easyhandle) {
+			f = fapi->fetch_feed(feed_id, *easyhandle);
+		} else {
+			f = fapi->fetch_feed(feed_id);
+		}
+
 	}
 	LOG(Level::INFO,
 		"RssParser::fetch_freshrss: f.items.size = %" PRIu64,
